class Libprelude < Formula
  desc "Universal Security Information & Event Management (SIEM) system"
  homepage "https://www.prelude-siem.org/"
  url "https://www.prelude-siem.org/attachments/download/1395/libprelude-5.2.0.tar.gz"
  sha256 "187e025a5d51219810123575b32aa0b40037709a073a775bc3e5a65aa6d6a66e"
  license "GPL-2.0-or-later"
  revision 2

  livecheck do
    url "https://www.prelude-siem.org/projects/prelude/files"
    regex(/href=.*?libprelude[._-]v?(\d+(?:\.\d+)+)\.t/i)
  end

  depends_on "pkg-config" => :build
  depends_on "python-setuptools" => :build
  depends_on "python@3.12" => [:build, :test]
  depends_on "gnutls"
  depends_on "libgpg-error"
  depends_on "libtool"

  # Fix compatibility with Python 3.10 or later using Debian patch.
  # ImportError: symbol not found in flat namespace '_PyIOBase_Type'
  patch do
    url "https://sources.debian.org/data/main/libp/libprelude/5.2.0-5/debian/patches/025-Fix-PyIOBase_Type.patch"
    sha256 "cd03b3dc208c2a4168a0a85465d451c7aa521bf0b8446ff4777f2c969be386ba"
  end

  def python3
    "python3.12"
  end

  def install
    ENV["HAVE_CXX"] = "yes"
    args = %W[
      --disable-silent-rules
      --without-valgrind
      --without-lua
      --without-ruby
      --without-perl
      --without-swig
      --without-python2
      --without-python3
      --with-libgnutls-prefix=#{Formula["gnutls"].opt_prefix}
    ]

    system "./configure", *std_configure_args, *args
    system "make"
    system "make", "install"

    # Work around Homebrew's "prefix scheme" patch which causes non-pip installs
    # to incorrectly try to write into HOMEBREW_PREFIX/lib since Python 3.10.
    # This is done by manually install python bindings.
    system python3, "-m", "pip", "install", *std_pip_args, "./bindings/python"
  end

  test do
    assert_equal prefix.to_s, shell_output(bin/"libprelude-config --prefix").chomp
    assert_equal version.to_s, shell_output(bin/"libprelude-config --version").chomp

    (testpath/"test.c").write <<~EOS
      #include <libprelude/prelude.h>

      int main(int argc, const char* argv[]) {
        int ret = prelude_init(&argc, argv);
        if ( ret < 0 ) {
          prelude_perror(ret, "unable to initialize the prelude library");
          return -1;
        }
      }
    EOS
    system ENV.cc, "test.c", "-L#{lib}", "-lprelude", "-o", "test"
    system "./test"

    (testpath/"test.py").write <<~EOS
      import prelude
      idmef = prelude.IDMEF()
      idmef.set("alert.classification.text", "Hello world!")
      print(idmef)
    EOS
    assert_match(/classification:\s*text: Hello world!/, shell_output("#{python3} test.py"))
  end
end
